yt.analysis_modules.halo_finding.halo_objects.FOFHalo.virial_radius — The yt Project 3.2-dev documentation

# yt.analysis_modules.halo_finding.halo_objects.FOFHalo.virial_radius

`FOFHalo.` `virial_radius`(*args, **kwargs)

  Return the virial radius of the halo in code units.

  The virial radius of the halo is calculated, using only the particles in the halo (no baryonic information used). Returns -1 if the halo is not virialized.

  Parameters: | virial_overdensity : float The overdensity threshold compared to the universal average when calculating the virial radius. Default = 200. bins : integer The number of spherical bins used to calculate overdensities. Default = 300.
  Returns: | radius : float The virial raius in code units of the particles in the halo. -1 if not virialized.

  Examples

      >>> vr = halos[0].virial_radius()